%% TU Delft iGEM 2009 team
%% Transcriptional cascade model
%%
%% This file can be used to find solutions to the system of ODEs
%%
%% parameter values should be changed in the parameters.m file
%%
%% October 10, 2009
%% Version 2.5

parameters %% grab parameters

assign_parameters %% grab parameters

% compile parameter vector

param = [k1;k2;k3;k4;a1;a2;a3;a4;c1;c2;c3;c4;n1;n2;n3;n4;d1m;d2m;d3m;d4m;n_IPTG;d1p;d2p;d3p;d4p;alp1;alp2;alp3;alp4;k_IPTG;IPTG_ext;LacI_total;K50_IPTG;k_IPTG_out];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ode parameters

y0      = [1e-16 1e-16 1e-8 1e-8 1e-16 1e-16 1e-6 1e-6 1e-16]; % initial values IPTGin tetRmRNA CImRNA RFPmRNA GFPmRNA tetR CI RFP GFP
tfinal  = 800;         % final simulation time [min]
tstep   = .1;           % time step 
MaxAbsT = 1.0;          % maximal step size;

opt = odeset('RelTol',1e-3,'AbsTol',1e-6);

%% simulation

[t,y] = ode45('ode_cascade',[0:tstep:tfinal],y0,opt,param);

%% find delay time

threshold = 10e-9; % if [mRNA gfp] above this, delay is over

index_of_end = 1; % Counter
for i = 1:length(y)
     if (y(i,9) >= threshold)
             index_of_end = i;
             delay_time = t(index_of_end)
             break
     end
     if i == length(y)
         delay_time = 888;
     end
end 


% plot

hax = figure(1);

clf;
axes1 = axes('Parent',hax);
concentrationpoltmax = 2e-6;
axis(axes1,[0 tfinal 0 concentrationpoltmax]); % xmin xmax ymin ymax
hold(axes1,'all');
xlabel('Time [min]');
ylabel('Concentration [M]');
delaystring = sprintf('For a threshold concentration of %0.2g M the Delay is %0.1f min with expression leakage of %0.1f%%.',threshold,delay_time,100*a_pLac);
title(delaystring);

plot(t,y(:,1),'m-',t,y(:,6),'c-',t,y(:,7),'b-',t,y(:,8),'r-',t,y(:,9),'g-');
legend('IPTG_{in}','TetR','CI','RFP','GFP');

