%% TU Delft iGEM 2009 team
%% Parameter Sweeps
%%
%% This file can be used to do parameter sweeps
%%
%% parameter values should be changed in the parameters.m file
%%
%% October 4, 2009
%% Version 4.2

% jobs available:
%
% 2d_leakage_lamp
% 2d_leakage_lamp_zoomin
% 2d_leakage_pTet
% 2d_leakage_pLac
% 2d_IPTG_ext_induce
% 3d_Clamp_vs_alpha4
% 3d_CpTet_vs_alpha2
% 3d_CpLac_vs_alpha1
% 3d_leakage_a2_vs_a4
% 3d_alpha1_vs_alpha2
% 3d_alpha2_vs_alpha4
% 3d_alpha1_vs_alpha4
% 3d_CpLac_vs_CpTet
% 3d_CpLac_vs_Clamp
% 3d_CpTet_vs_Clamp
% 3d_dmRNA_vs_dTetR
% 3d_dCI_vs_dGFP
%
% example:
% joblist = {'3d_dmRNA_vs_dTetR','3d_dCI_vs_dGFP'};
%
% jobs can take a long time to complete depending on number of points
% selected

joblist = {'3d_leakage_a2_vs_a4'};

for imain = 1:length(joblist)

    clear parameter1 parameter2 delay_time
    
    tic % start clock

    parameters %% grab parameters

    assign_parameters %% grab parameters

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % ode parameters

    y0      = [1e-16 1e-16 1e-8 1e-8 1e-16 1e-16 1e-6 1e-6 1e-16]; % initial values IPTGin tetRmRNA CImRNA RFPmRNA GFPmRNA tetR CI RFP GFP
    tfinal  = 500;         % final simulation time [min]
    tstep   = .1;          % time step 
    MaxAbsT = 1.0;         % maximal step size;

    opt = odeset('RelTol',1e-3,'AbsTol',1e-6);

    variable_to_sweep = joblist{imain};

    para_flag = 'initpara';
    sweepcases

    % NOTE ON SIMULATION TIMES:
    % 1600 data points takes 11 min
    % 100 data points takes 1 min

    for index1 = 1:length(parameter1)
        %% choose parameter1
        para_flag = 'assign1';
        sweepcases

        for index2 = 1:length(parameter2)
            %% choose parameter2
            para_flag = 'assign2';
            sweepcases

            paramall = [k1;k2;k3;k4;a1;a2;a3;a4;c1;c2;c3;c4;n1;n2;n3;n4;d1m;d2m;d3m;d4m;n_IPTG;d1p;d2p;d3p;d4p;alp1;alp2;alp3;alp4;k_IPTG;IPTG_ext;LacI_total;K50_IPTG;k_IPTG_out];
            [t,y] = ode45('ode_cascade',[0:tstep:tfinal],y0,opt,paramall);

            %% find delay time

            threshold = 10e-9; % if [gfp] above this, delay is over

            index_of_end = 1; % Counter
            for i = 1:length(y)
                 if (y(i,9) >= threshold)
                         index_of_end = i;
                         delay_time(index2,index1) = t(index_of_end);
                         break
                 end
                 if i == length(y)
                     delay_time(index2,index1) = 800; %% delay is infinity
                 end
            end 
        end
    end

    para_flag = 'plot';
    sweepcases

    toc % print execution time
    printmsg = strcat('to run ', variable_to_sweep)
end
